/*
 *   libdanceracpi - Dancer's ACPI monitoring system modules
 *   Copyright (C) 2002 Junichi Uekawa
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef __LIBDANCERACPI_H__
#define __LIBDANCERACPI_H__

/// the API version of DACPI.
#define DACPI_API_VERSION 1

/**
   A battery status structure.
   Used for low-level functions.
 */
typedef struct dacpi_battery_status
{
  /// the API version
  int api_version;
  /// the rate the power is consumed: mW
  long rate;
  /// the capacity mWh
  long capacity;
  /// the voltage mV
  long voltage;
}dacpi_battery_status;

/**
   A battery status structure.
   Used for low-level functions.
 */
typedef struct dacpi_battery_info
{
  /// the API version
  int api_version;
  /// designed capacity of battery in mWh
  long designcapacity;
  /// the last full capacity of battery in mWh
  long lastfullcapacity;
  /// the designed voltage in mV
  long designvoltage;
  /// design capacity warning in mWh (dunno what it is, info?)
  long designcapacitywarning;
  /// design capacity low ? mWh
  long designcapacitylow;
  /// capacity granularity (no idea) mWh
  long capacitygranularity1;
  /// capacity granularity (no idea) mWh
  long capacitygranularity2;
}dacpi_battery_info;


/**
   Finds the status of the ACPI.

   This is a very low level function, don't use this.

   @returns 0 on success, 1 on out-of-memory, 2 on file-open fail.
 */
int 
dacpi_getbatterystatus(int battery_id /** ID of battery */, 
		       dacpi_battery_status * st /** Return structure. */);

/**
   Finds the info of the ACPI.
   
   This is a very low-level function, don't use this.
   
   @returns 0 on success, 1 on out-of-memory, 2 on file-open fail.
 */
int 
dacpi_getbatteryinfo(int battery_id /** ID of battery */, 
		       dacpi_battery_info * info /** Return structure. */);


/**
   The v2 structure. Esier to handle, to obtain information about the battery.
   Used in dacpi_get_battery function.
 */
typedef struct dacpi_battery
{
  /// the API version
  int api_version;
  /// the max possible battery. mWh
  long battery_max;		
  /// the current battery status, remaining. mWh
  long battery_current;
  /// the battery is used at this speed. mW
  long battery_using;
} dacpi_battery;

/**
 * A higher level function to get battery info.
 */
int dacpi_get_battery (int battery_id, dacpi_battery * b);


/**
   The return type for dacpi_get_ac_adapter
 */
typedef enum
  {
    /// some error occurred (dacpi_get_ac_adapter)
    DACPI_AC_ERROR=0,
    /// AC is online (dacpi_get_ac_adapter)
    DACPI_AC_ONLINE,
    /// AC is offline (dacpi_get_ac_adapter)
    DACPI_AC_OFFLINE
  } DACPI_ADAPTER_TYPE;

/**
 * A function to obtain on-line status of ac adapter.
 * one of DACPI_AC_OFFLINE, DACPI_AC_ONLINE, or DACPI_AC_ERROR
 */
DACPI_ADAPTER_TYPE dacpi_get_ac_adapter (int ac_id/** The AC ID (don't ask me how to obtain this value) */);

/// get the battery status, the usage rate (mW)
long dacpi_get_battery_using (int battery_id);
/// get the battery status. the max mWh
long dacpi_get_battery_max (int battery_id);
/// get the battery status. the current remaining (mWh)
long dacpi_get_battery_current (int battery_id);


/**
   function to check the availability of /proc ACPI support.
   returns true of it is supported, otherwise false.
 */
int dacpi_check_acpi_support (void);

/**
   get the library API version.
   Check against DACPI_API_VERSION to see if things seem to be matching.
   It should work across API versions, but some warning might be in order..
 */
int dacpi_obtain_library_api_version (void);

#endif
